/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EjbJarFieldMetadata.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ejbjar.impl;

import org.ow2.util.ee.deploy.api.deployable.EJBDeployable;
import org.ow2.util.ee.metadata.common.impl.CommonFieldMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarClassMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarDeployableMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarFieldMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarMethodMetadata;
import org.ow2.util.scan.api.metadata.structures.JField;

/**
 * This class represents the annotation metadata of a field.
 * @param <E> an implementation of EJBDeployable
 * @param <D> an implementation of IEjbJarDeployableMetadata
 * @param <C> an implementation of IEjbJarClassMetadata
 * @param <M> an implementation of IEjbJarMethodMetadata
 * @param <F> an implementation of IEjbJarFieldMetadata
 * @author Florent Benoit
 */
public class EjbJarFieldMetadata<
    E extends EJBDeployable<E>,
    D extends IEjbJarDeployableMetadata<E, D, C, M, F>,
    C extends IEjbJarClassMetadata<E, D, C, M, F>,
    M extends IEjbJarMethodMetadata<E, D, C, M, F>,
    F extends IEjbJarFieldMetadata<E, D, C, M, F>>
        extends CommonFieldMetadata<C, M, F> implements IEjbJarFieldMetadata<E, D, C, M, F> {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = -7721676662944506087L;

    /**
     * Logger.
     */
    //private static Log logger = LogFactory.getLog(FieldAnnotationMetadata.class);


    /**
     * Constructor.
     * @param jField the field on which we will set/add metadata
     * @param classAnnotationMetadata the parent metadata.
     */
    public EjbJarFieldMetadata(final JField jField, final C classAnnotationMetadata) {
        super(jField, classAnnotationMetadata);
    }

    /**
     * @return name of the field
     */
    public String getFieldName() {
        return getJField().getName();
    }

    /**
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        String titleIndent = " ";
        String indent = "   ";
        // classname
        sb.append(titleIndent);
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));
        sb.append("[\n");

        // Add super class toString()
        sb.append(super.toString());

        // Field
        sb.append(indent);
        sb.append("jField=");
        sb.append(getJField());
        sb.append("\n");

        // inherited
        if (isInherited()) {
            sb.append(indent);
            sb.append("inherited=true");
            sb.append("\n");
        }

        sb.append(titleIndent);
        sb.append("]\n");
        return sb.toString();
    }

}
